==> otyacraftengine-forge-2.4-sources.jar: dev/felnull/otyacraftengine/client/gui/components/base/OEBaseWidget.java <==
package dev.felnull.otyacraftengine.client.gui.components.base;

import net.minecraft.client.Minecraft;
import net.minecraft.client.gui.components.AbstractWidget;
import net.minecraft.client.gui.narration.NarratedElementType;
import net.minecraft.client.gui.narration.NarrationElementOutput;
import net.minecraft.network.chat.Component;
import net.minecraft.network.chat.MutableComponent;
import net.minecraft.network.chat.TranslatableComponent;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

public abstract class OEBaseWidget extends AbstractWidget implements IOEBaseComponent {
    @Nullable
    private final String widgetTypeName;

    public OEBaseWidget(int x, int y, int width, int height, Component component) {
        this(x, y, width, height, null, component);
    }

    public OEBaseWidget(int x, int y, int width, int height, @Nullable String widgetTypeName, @NotNull Component message) {
        super(x, y, width, height, message);
        this.widgetTypeName = widgetTypeName;
    }

    @Override
    public void m_142291_(@NotNull NarrationElementOutput narrationElementOutput) {
        this.m_168802_(narrationElementOutput);
    }

    @Override
    protected void m_168802_(NarrationElementOutput narrationElementOutput) {
        narrationElementOutput.m_169146_(NarratedElementType.TITLE, this.m_5646_());
        if (this.widgetTypeName != null && this.f_93623_) {
            if (this.m_93696_()) {
                narrationElementOutput.m_169146_(NarratedElementType.USAGE, new TranslatableComponent("narration." + widgetTypeName + ".usage.focused"));
            } else {
                narrationElementOutput.m_169146_(NarratedElementType.USAGE, new TranslatableComponent("narration." + widgetTypeName + ".usage.hovered"));
            }
        }
    }

    @Override
    protected MutableComponent m_5646_() {
        if (widgetTypeName == null)
            return new TranslatableComponent("gui.narrate.widget", m_6035_());
        return new TranslatableComponent("gui.narrate." + widgetTypeName, m_6035_());
    }

    @Override
    public void m_5716_(double d, double e) {
        this.onPress();
    }

    @Override
    public boolean m_7933_(int i, int j, int k) {
        if (this.f_93623_ && this.f_93624_) {
            if (i != 257 && i != 32 && i != 335) return false;
            this.m_7435_(Minecraft.m_91087_().m_91106_());
            this.onPress();
            return true;
        }
        return false;
    }

    public abstract void onPress();

    public @Nullable String getWidgetTypeName() {
        return widgetTypeName;
    }
}

==> otyacraftengine-forge-3.2.0-pre.5-sources.jar: dev/felnull/otyacraftengine/client/gui/components/base/OEBaseWidget.java <==
package dev.felnull.otyacraftengine.client.gui.components.base;

import net.minecraft.client.Minecraft;
import net.minecraft.client.gui.components.AbstractWidget;
import net.minecraft.client.gui.narration.NarratedElementType;
import net.minecraft.client.gui.narration.NarrationElementOutput;
import net.minecraft.network.chat.Component;
import net.minecraft.network.chat.MutableComponent;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

public abstract class OEBaseWidget extends AbstractWidget implements IOEBaseComponent {
    @Nullable
    private final String widgetTypeName;

    public OEBaseWidget(int x, int y, int width, int height, @NotNull Component message) {
        this(x, y, width, height, null, message);
    }

    public OEBaseWidget(int x, int y, int width, int height, @Nullable String widgetTypeName, @NotNull Component message) {
        super(x, y, width, height, message);
        this.widgetTypeName = widgetTypeName;
    }

    @Override
    public void m_142291_(@NotNull NarrationElementOutput narrationElementOutput) {
        this.m_168802_(narrationElementOutput);
    }

    @Override
    protected void m_168802_(NarrationElementOutput narrationElementOutput) {
        narrationElementOutput.m_169146_(NarratedElementType.TITLE, this.m_5646_());
        if (this.widgetTypeName != null && this.f_93623_) {
            if (this.m_93696_()) {
                narrationElementOutput.m_169146_(NarratedElementType.USAGE, Component.m_237115_("narration." + widgetTypeName + ".usage.focused"));
            } else {
                narrationElementOutput.m_169146_(NarratedElementType.USAGE, Component.m_237115_("narration." + widgetTypeName + ".usage.hovered"));
            }
        }
    }

    @Override
    protected MutableComponent m_5646_() {
        if (widgetTypeName == null)
            return Component.m_237110_("gui.narrate.widget", m_6035_());
        return Component.m_237110_("gui.narrate." + widgetTypeName, m_6035_());
    }

    @Override
    public void m_5716_(double d, double e) {
        this.onPress();
    }

    @Override
    public boolean m_7933_(int i, int j, int k) {
        if (this.f_93623_ && this.f_93624_) {
            if (i != 257 && i != 32 && i != 335) return false;
            this.m_7435_(Minecraft.m_91087_().m_91106_());
            this.onPress();
            return true;
        }
        return false;
    }

    public abstract void onPress();

    public @Nullable
    String getWidgetTypeName() {
        return widgetTypeName;
    }
}
